@@ -2,7 +2,8 @@
 #define HITACHI_H
 
 #include "pirkeysetmetadata.h"
-#include <QObject>
+
+class QObject;
 
 class HitachiTV1: public PIRKeysetMetaData
 {
@@ -36,6 +37,22 @@ public:
     unsigned int index);
 };
 
+class HitachiTV2: public PIRKeysetMetaData
+{
+public:
+  HitachiTV2(
+    QObject *guiObject,
+    unsigned int index);
+};
+
+class HitachiTV3: public PIRKeysetMetaData
+{
+public:
+  HitachiTV3(
+    QObject *guiObject,
+    unsigned int index);
+};
+
 class HitachiProjector: public PIRKeysetMetaData
 {
 public:
