@@ -13,8 +13,10 @@ enum PIRMakeName{
   Bose_Make,
   Daewoo_Make,
   Denon_Make,
+  DigitalStream_Make,
   Ei_Make,
   Elgato_Make,
+  Emerson_Make,
   GoldStar_Make,
   Grundig_Make,
   Hauppauge_Make,
